#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import pymysql


class SQLMaster(object):

    def __init__(self, host: str, user: str, password: str, db: str, port: int = 3306):
        """
        初始化数据库连接
        :param host:           数据库主机地址
        :param user:           连接用户
        :param password:       连接密码
        :param db:             目标数据库
        :param port:           数据库连接端口，默认3306
        """
        try:
            self.db = db
            self.connection = pymysql.connect(host=host, port=port, user=user, passwd=password, db=db, charset='utf8')
            print('[SQLMaster] - mysql database [%s] connect success...' % db)
        except Exception as e:
            print('[SQLMaster] - mysql database [%s] connect failure...' % db)
            print(repr(e))

    def close(self):
        """
        关闭数据库连接
        """
        try:
            if self.connection:
                self.connection.close()
            print('[SQLMaster] - mysql database [%s] closed success...' % self.db)
        except Exception as e:
            print('[SQLMaster] - mysql database [%s] closed failure...' % self.db)
            print(repr(e))

    def execute(self, sql: str):
        """
        执行插入、修改、删除等操作
        :param sql:            sql语句
        :return:               返回执行是否成功的bool
        """
        with self.connection.cursor() as cursor:
            try:
                cursor.execute(sql)
                self.connection.commit()
                print("[SQLMaster] - execute success...")
                return True
            except Exception as e:
                print("[SQLMaster] - execute failure...")
                print("[SQLMaster] - %s" % repr(e))
                return False
            finally:
                pass
                # if cursor:
                #     cursor.close()

    def fetch(self, sql: str):
        """
        执行结果查询操作
        :param sql:            sql语句
        :return:               查询成功返回结果元组，元组中的每一个item也是一个元组，读取数据时按index读取
                               例如：
                                    for row in rows:
                                        id = row[0]
        """
        with self.connection.cursor() as cursor:
            try:
                cursor.execute(sql)
                result_rows = cursor.fetchall()
                if result_rows is None or len(result_rows) <= 0:
                    print("[SQLMaster] - execute failure... no result found")
                    return None
                print("[SQLMaster] - execute success...")
                return result_rows
            except Exception as e:
                print("[SQLMaster] - execute failure...")
                print("[SQLMaster] - %s" % repr(e))
                return None
            finally:
                pass
                # if cursor:
                #     cursor.close()


if __name__ == '__main__':
    connection = SQLMaster(host='localhost', user='root', password='xx', db='wiatec_movie')
    connection.execute('UPDATE m_video SET title = "1123" WHERE id = 2')
    connection.fetch(sql='SELECT * FROM m_video WHERE id > 0')
    connection.close()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from Crypto.Cipher import AES
import hashlib
import binascii
import jwt
from datetime import datetime, timedelta


ENCODING = "utf-8"
AES_IV = "2018071119861008"
AES_DEFAULT_KEY = "&h24*3)u6@m#,1p~7k&/q!=6h^l*"

JWT_DEFAULT_ISSUER = "ex"
JWT_DEFAULT_SUBJECT = "auth"
JWT_SECRET = "#hhjkhkh&jh2432@ndsf*_erkhwek234&ewhkjwehr^hfh234$2l3j4o32urMiOiJ3a" \
             "Jpc3MiOiJ3aWF0ZWMiLCJzdWIiOiJsZWdhY3kiLCJuYmYiOjE1MjAyNjE5NTgsImJzd" \
             "WIiOiJsZWdhY3kiLCJuYmYiOjE1MjAyNjQ0MjksImV4cCI6MTUyMDM1MD2l3j4o3"


def md5(source: str):
    return hashlib.md5(source.encode(ENCODING)).hexdigest()


def md5_16(source: str):
    return hashlib.md5(source.encode(ENCODING)).hexdigest()[8: 24]


class AesMaster:

    @staticmethod
    def encrypt(source: str, key: str = AES_DEFAULT_KEY, iv: str = AES_IV):
        """
        加密
        """
        amount_to_pad = AES.block_size - (len(source) % AES.block_size)
        if amount_to_pad == 0:
            amount_to_pad = AES.block_size
        raw = source + chr(amount_to_pad) * amount_to_pad
        key = str(hashlib.md5(key.encode(ENCODING)).hexdigest()).encode(encoding=ENCODING)
        cipher = AES.new(key, AES.MODE_CBC, iv=iv.encode(encoding=ENCODING))
        encrypt_bytes = cipher.encrypt(raw.encode(ENCODING))
        return str(binascii.b2a_hex(encrypt_bytes).decode(ENCODING))

    @staticmethod
    def decrypt(source: str, key: str = AES_DEFAULT_KEY, iv: str = AES_IV):
        """
        解密
        """
        enc = binascii.a2b_hex(source)
        key = str(hashlib.md5(str(key).encode(ENCODING)).hexdigest()).encode(encoding=ENCODING)
        cipher = AES.new(key, AES.MODE_CBC, iv=iv.encode(encoding=ENCODING))
        decrypt_bytes = cipher.decrypt(enc)
        return str(decrypt_bytes.decode(ENCODING)).replace('\n', '')


class JwtMaster(object):

    @staticmethod
    def encrypt(expires_days: int = 7, issuer: str = JWT_DEFAULT_ISSUER, subject: str = JWT_DEFAULT_SUBJECT):
        """
        加密生成JWT token
        :param expires_days:   token过期天数
        :param issuer:         token发行者
        :param subject:        token主题
        :return:               token字符串
        """
        payload = {
            "sub": subject,
            "iss": issuer,
            "iat": datetime.utcnow(),
            "nbf": datetime.utcnow(),
            "exp": datetime.utcnow() + timedelta(days=expires_days),
        }
        return jwt.encode(payload=payload, key=JWT_SECRET, algorithm="HS256")

    @staticmethod
    def decrypt(token_str: str):
        """
        解密JWT token
        :param token_str:      jwt token
        :return:               返回token中包含的payload字典
                                    {'sub': 'auth', 'iss': 'ex', 'iat': 1628499184, 'nbf': 1628499184, 'exp': 1629103984}
        """
        return jwt.decode(token_str, JWT_SECRET, algorithms=['HS256'])


if __name__ == '__main__':
    encrypt = AesMaster.encrypt('test content')
    print(encrypt)
    decrypt = AesMaster.decrypt(encrypt)
    print(decrypt)
    token = JwtMaster.encrypt()
    print(token)
    result = JwtMaster.decrypt(token)
    print(result)
    print(md5('123'))
    print(md5_16('123'))
